<?php
namespace Ems\portalGestor\Controller;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DTO\Response\{ Message, Error };
use Zeedhi\Framework\DataSource\DataSet;

use Ems\portalGestor\Service\ResumoService;
use Ems\portalGestor\Util\ExpectedException;

class ResumoController {
    /** @var ResumoService */
    protected $resumoService;

    public function __construct(
        ResumoService $resumoService
    ) {
      $this->resumoService = $resumoService;
    }

    public function getSituacoesFreq(
        Request\Filter $request,
        Response $response
    ) {
        try {
            $row = $request->getParameters();
            $nrOrg = (int) $row['NRORG'];

            $situacoes = $this->resumoService->getSituacoesFreq(
                $nrOrg
            );

            $response->addDataSet(new DataSet('data', $situacoes));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace()));
        }
    }

    public function getResumoFreq(
        Request\Filter $request,
        Response $response
    ) {
        try {
            $row = $request->getParameters();

            $resumo = $this->resumoService->getResumoFreq(
                $row
            );

            $response->addDataSet(new DataSet('data', $resumo));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace()));
        }
    }

    public function saveResumoFreq(
        Request\Row $request,
        Response $response
    ) {
        try {
            $row = $request->getRow()->getArrayCopy();

            $success = $this->resumoService->saveResumoFreq(
                $row
            );

            $dataSet = [
                'success' => $success,
            ];

            $response->addDataSet(new DataSet('data', $dataSet));
        } catch (ExpectedException $e) {
            $response->addMessage(new Message($e->getMessage(), Message::TYPE_ERROR));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace()));
        }
    }

    public function gestorCanEditResumo(
        Request\Filter $request,
        Response $response
    ) {
        try {
            $row = $request->getParameters();

            $candEdit = $this->resumoService->gestorCanEditResumo(
                $row
            );

            $dataSet = [
                'canEdit' => $candEdit,
            ];

            $response->addDataSet(new DataSet('data', $dataSet));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace()));
        }
    }
}